RobotPy WPILib API Documentation
================================

RobotPy WPILib is the source code for python wrappers around the C++ implementation
of WPILib, the library used to interface with hardware for the FIRST Robotics
Competition. Teams can use this library to write their robot code in Python,
a powerful dynamic programming language.

.. Note:: RobotPy is a community project and is not officially supported by
          FIRST. Please see the `FAQ <https://robotpy.github.io/faq/>`_ for
          more information.

.. include:: _sidebar.rst.inc
    
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`